#! /usr/bin/env python

#arg 1 RA of IHMP center
#arg 2 Dec of IHMP center
#arg 3 angle of IHMP  (all from remedy)
#arg 4 correction for differential atmospheric dispersion
#arg 5 RA of target star
#arg 6 Dec of target star

from astropy import wcs
import numpy as np

import sys

ARCSECPERDEG = 1.0/3600.0

# make a WCS object with appropriate FITS headers
tp = wcs.WCS(naxis=2)
tp.wcs.crpix = [0., 0.]  # central "pixel"
tp.wcs.crval = [np.float(sys.argv[1]),
                np.float(sys.argv[2])]  # tangent point
tp.wcs.ctype = ['RA---TAN', 'DEC--TAN']
# pixel scale in arcsecond

x_scale=-1.

y_scale=1.
    
tp.wcs.cdelt = [ARCSECPERDEG * x_scale,
                       ARCSECPERDEG * y_scale]

# Put rotation into radians
rrot = np.deg2rad(np.float(sys.argv[3]))
# clockwise rotation matrix
tp.wcs.pc = [[np.cos(rrot), np.sin(rrot)], [-1.0*np.sin(rrot), np.cos(rrot)]]

FPLANE_Y, FPLANE_X = tp.wcs_world2pix(np.float(sys.argv[5]),
                                      np.float(sys.argv[6]), 1)

#apply atmospheric dispersion correction
FPLANE_Y += np.float(sys.argv[4])

print('fplane x,y='+str(FPLANE_X)+','+str(FPLANE_Y))

